@@ -32,11 +32,15 @@ logfile=""
 StartTime=0
 StartTimeSec=0
 StopTime=0
+ChangesInGraph=0
+run=0
+Mode=0
 
 version="0"
 build="0"
 user=""
 app_path="./"
+passed_time=0
 
 #arrays, indexes, lenghts
 arrDataLen=4680 #(1 value/10sec for 13h), 6*13*60
