@@ -22,8 +22,10 @@ import ConfigParser
 import os, os.path
 
 
+
 import data #own data
 from myFunctions import * #Own functions
+#from myMP3 import * #Own functions to play an MP3
 
 #GUIs
 from Ui_StartWindow import *
@@ -107,14 +109,19 @@ def main():
 ###########################################################################
 def TimerLoop():
     global CollectingWindowGraph
+    
+#    Show_passed_time("TimerLoop start")
 
     r=GetSensorData() #(interval: sampling*sample_smoothing*value_smoothing)
     if(r==1):
         WriteIntoLogFile()
         ProcessData() 
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
         CollectingWindowGraph.update() #show CollectingWindowGraph    
     
-    CollectingWindow.UpdateScreen()
+    CollectingWindow.UpdateScreen()    
+    
+#    Show_passed_time("TimerLoop end")
 
   
   
@@ -126,7 +133,8 @@ def TimerLoop():
 def ShowCollectingWindow():
     CollectingWindow.show()
     StartWindow.hide()
-    StartMeasurement(data.sampling)
+    data.Mode=0 #run in normal mode
+    ToggleMeasurement()
     
     
 ###########################################################################
@@ -135,7 +143,8 @@ def ShowCollectingWindow():
 def ShowCollectingWindowTest():
     CollectingWindow.show()
     StartWindow.hide()
-    StartMeasurement(10)
+    data.Mode=1 #run in quick mode (for testing only)
+    ToggleMeasurement()
     data.Xscale=0 #default zoom level
     data.test=1 #hide axis lables
     
@@ -174,6 +183,9 @@ def ZoomIn():
     else: LogWindow.ui.bZoomIn.setEnabled(True)
     data.Xscale=(data.Xscale-1) % data.arrXscaleLen
     ProcessData()
+    Show_passed_time("## ZoomIn")
+    data.ChangesInGraph=1 #Make sure it only gets refreshed once
+    CollectingWindow.update()
     LogWindow.update()
 
 def ZoomOut():
@@ -183,6 +195,9 @@ def ZoomOut():
     else: LogWindow.ui.bZoomOut.setEnabled(True)
     data.Xscale=(data.Xscale+1) % data.arrXscaleLen
     ProcessData()
+    Show_passed_time("## ZoomIn")
+    data.ChangesInGraph=1 #Make sure it only gets refreshed once
+    CollectingWindow.update()
     LogWindow.update()
 
 
@@ -196,12 +211,12 @@ def StartMeasurement(interval):
     global CollectingWindowGraph
     global app
     
-    StartLogfile(interval)
-    
     #init value
     data.sample_index=0
     data.values_total=0
     data.arrDataIndex=0
+    
+    StartLogfile(interval)
         
     CollectingWindowGraph = CollectingWindowCanvas()
     data.Xscale=1 #default zoom level
@@ -217,6 +232,7 @@ def StartMeasurement(interval):
     app.timer_GetData = QtCore.QTimer()
     QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)        
     app.timer_GetData.start(interval)
+    data.run=1
     
     CollectingWindow.UpdateScreenStart()
     
@@ -226,13 +242,26 @@ def StartMeasurement(interval):
 ###########################################################################
 # Stop the measurement
 ###########################################################################
-def StopMeasurement():
+def ToggleMeasurement():
     global app
-    print "Stop timers..."
-    app.timer_GetData.stop()
-    StopLogfile()       
-    CollectingWindow.UpdateScreenStop()
-    data.test=0 # reset test mode if was active
+    if(data.run==0): #not running
+        data.run=1
+        print "data.Mode:",  data.Mode,  data.sampling
+        if(data.Mode==0):
+            StartMeasurement(data.sampling) #normal
+        else:  
+            StartMeasurement(10) #Fast mode for testing
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
+    else: #running
+        data.run=0
+        print "Stop timers..."
+        app.timer_GetData.stop()
+        data.run=0
+        StopLogfile()       
+        CollectingWindow.UpdateScreenStop()
+        data.test=0 # reset test mode if was active
+    
+    
 
 
 
@@ -244,6 +273,9 @@ def RaiseTrigger():
     data.trigger=data.trigger+1
     if(data.trigger>100): data.trigger=100
     ProcessData()
+    data.ChangesInGraph=1 #Make sure it only gets refreshed once
+    CollectingWindow.update()
+    CollectingWindow.UpdateScreen()
     LogWindow.update() 
     LogWindow.UpdateScreen()
     
@@ -257,6 +289,9 @@ def LowerTrigger():
     data.trigger=data.trigger-1
     if(data.trigger<0): data.trigger=0
     ProcessData()
+    data.ChangesInGraph=1 #Make sure it only gets refreshed once
+    CollectingWindow.update()
+    CollectingWindow.UpdateScreen()
     LogWindow.update()
     LogWindow.UpdateScreen()
    
@@ -271,7 +306,12 @@ def LowerTrigger():
 # the parameter indcates on which window it will be drawn
 ###########################################################################
 def showGraph(self):
-#        print "Show Graph"
+        Show_passed_time("showGraph Start")
+        if(data.ChangesInGraph==0): 
+            if(data.debug==1): print "------>         Do not redraw, nothing changed!"
+            return 
+            
+        data.ChangesInGraph=0
         paint = QtGui.QPainter()
         paint.begin(self)
 
@@ -298,7 +338,6 @@ def showGraph(self):
         except:
             h0=int(strftime("%H", time.localtime()))
             m0=int(strftime("%M", time.localtime()))
-        # 1 minute = 1 px
 #        print "Start time of graph:",  h0,  m0
 
         
@@ -314,6 +353,9 @@ def showGraph(self):
         minutestonexthour=60-m0
         offset=minutestonexthour*decade/60
         
+        
+        Show_passed_time("2")
+        
         #main lines + text
         if(data.test==0):
             for i in range(0, 781+decade,  decade):
@@ -332,6 +374,8 @@ def showGraph(self):
         paint.drawLine(1, y-15, 781, y-15)  
 
 
+        Show_passed_time("4")
+
         #draw graph
         lastmove=0
 #        print shift,  data.arrDataIndex-data.derivation,  Xscale
@@ -344,8 +388,10 @@ def showGraph(self):
             
             #when Xscale is small, we have to merge several records into 1 pixel.
             #To not miss any movement, we use the biggest movement of the merged records:
-            peak=0
+            peak=0            
+            paint.setPen(QtGui.QColor("yellow"))
             for j in range(0, Xscale):
+#                Show_passed_time("L 1")
                 p=abs(data.arrData[3][k])+abs(data.arrData[4][k])
                 if(p>peak): peak=p
            
@@ -356,8 +402,7 @@ def showGraph(self):
 #                peak=abs(data.arrData[3][k])+abs(data.arrData[4][k])
             Y=peak*data.Yscale
             #Draw movement line
-            paint.setPen(QtGui.QColor("yellow"))
-            paint.setBrush(QtGui.QColor("yellow"))
+#            paint.setBrush(QtGui.QColor("yellow"))
             paint.drawLine(i/Xscale, data.Ysize-Y-1-15, i/Xscale, data.Ysize-1-15)  
             
             
@@ -365,6 +410,11 @@ def showGraph(self):
 #                if(k>lastmove+1):k
 #            print i,  end,  Xscale
             if(peak>data.trigger or i>=end-Xscale):
+                
+#                if(data.Mode==1): #quick mode for testing
+#                    playMP3() #make beep for testing
+                
+#                Show_passed_time("L 2")
 ##                    1=10 sec
 #                    if((i-lastmove)>30*Xscale): color="#009100" #green
 #                    elif((i-lastmove)>15*Xscale): color="#005000" #dark green
@@ -384,10 +434,12 @@ def showGraph(self):
                     else: color="#6D0000" #dark red                         
                     paint.setBrush(QtGui.QColor(color))
                     paint.setPen(QtGui.QColor(color))
-                    paint.drawRect(x0, data.Ysize-11, x1-x0, 10) 
+                    paint.drawRect(x0, data.Ysize-11, x1-x0, 10)                     
+                    paint.setPen(QtGui.QColor("yellow"))
 #                        print "=     Draw field",  x0,  x1,  data.Ysize,  color
                 lastmove=i
 
+        Show_passed_time("showGraph End")
 
 
 
@@ -401,11 +453,12 @@ def DeleteLogFile():
 
 
 def ShowLogFile():
-    OpenLogFile()
+    OpenLogFile()    
     ProcessData()
     LogWindow.UpdateScreen()
     LogWindowGraph = LogWindowCanvas()
     data.Xscale=1 #default zoom level
+    data.ChangesInGraph=1 #Make sure it only gets refreshed once
     LogWindowGraph.show()
 
 ###########################################################################
@@ -472,6 +525,12 @@ class frmStartWindow(QtGui.QWidget):
         QtCore.QObject.connect(self.ui.bCollecting, QtCore.SIGNAL("clicked()"), ShowCollectingWindow)
         QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), ShowLogWindow)
         QtCore.QObject.connect(self.ui.bQuick, QtCore.SIGNAL("clicked()"), ShowCollectingWindowTest)
+        
+        if(data.app_path!="./"): #only needed if not started in app path
+            self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"SleepAnalyser.png"))
+            self.ui.bQuick.setIcon(QIcon(data.app_path+"krec.png"))
+            self.ui.bCollecting.setIcon(QIcon(data.app_path+"krec.png"))
+            self.ui.bLog.setIcon(QIcon(data.app_path+"zoom.png"))
 
     def UpdateScreenStart(self):
         try:   
@@ -505,7 +564,18 @@ class frmCollectingWindow(QtGui.QWidget):
         self.ui = Ui_CollectingWindow()
         self.ui.setupUi(self)
         
-        QtCore.QObject.connect(self.ui.bStop, QtCore.SIGNAL("clicked()"), StopMeasurement)
+        QtCore.QObject.connect(self.ui.bStop, QtCore.SIGNAL("clicked()"), ToggleMeasurement)
+        QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), RaiseTrigger)
+        QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), LowerTrigger)
+        QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), ZoomIn)
+        QtCore.QObject.connect(self.ui.bZoomOut, QtCore.SIGNAL("clicked()"), ZoomOut)
+        
+        if(data.app_path!="./"): #only needed if not started in app path
+            self.ui.bZoomIn.setIcon(QIcon(data.app_path+"zoom-in.png"))
+            self.ui.bZoomOut.setIcon(QIcon(data.app_path+"zoom-out.png"))
+            self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"go-up.png"))
+            self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"go-down.png"))
+            
 
     def UpdateScreen(self):
         if(data.demo==0):
@@ -515,7 +585,7 @@ class frmCollectingWindow(QtGui.QWidget):
 
         t=time.mktime(time.localtime())
         time_difference=t-data.StartTimeSec
-        t=strftime("%H:%M:%S", time.localtime(time_difference))
+        t=strftime("%H:%M:%S", time.gmtime(time_difference))
         self.ui.lblElapsedTime.setText(t)
             
 
@@ -528,14 +598,26 @@ class frmCollectingWindow(QtGui.QWidget):
         self.ui.lblYscale.setText(str(data.Yscale))
         self.ui.lblTrigger.setText(str(data.trigger*data.Yscale))
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"SleepAnalyser.png"))
+        self.ui.bStop.setIcon(QIcon(data.app_path+"krec2.png"))
+        self.ui.bStop.setText("Stop recording")
         
         
     def UpdateScreenStop(self):
         self.ui.lblSamples_Taken.setText(str(data.values_total)+" (Stopped)")
+        self.ui.bStop.setIcon(QIcon(data.app_path+"krec.png"))
+        self.ui.bStop.setText("Start recording")
+        
+
 
 
     def closeEvent(self, event):
-        StopMeasurement()
+        #check if user wants to keep this record
+        reply = QtGui.QMessageBox.question(self, 'Keep Logfile?', "Do you want to keep this Record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+        if reply == QtGui.QMessageBox.No:
+            print "Delete logfile: "+data.logfilename
+            os.remove(data.logfolder+data.logfilename)
+            
+        if(data.run==1): ToggleMeasurement()
         StartWindow.show()
 #        NoteWindow.show()
         CollectingWindow.close() 
@@ -566,12 +648,15 @@ class frmLogWindow(QtGui.QWidget):
         QtCore.QObject.connect(self.ui.bLast, QtCore.SIGNAL("clicked()"), LastLogFile)
         QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), DeleteLogFile)
         
-        #only needed if application is not started in app path
-        self.ui.bZoomIn.setIcon(QIcon(data.app_path+"zoom-in.png"))
-        self.ui.bZoomOut.setIcon(QIcon(data.app_path+"zoom-out.png"))
-        self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"go-up.png"))
-        self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"go-down.png"))
-        
+        if(data.app_path!="./"): #only needed if not started in app path
+            self.ui.bLast.setIcon(QIcon(data.app_path+"go-previous.png"))
+            self.ui.bNext.setIcon(QIcon(data.app_path+"go-next.png"))
+            self.ui.bDelete.setIcon(QIcon(data.app_path+"edittrash.png"))
+            self.ui.bZoomIn.setIcon(QIcon(data.app_path+"zoom-in.png"))
+            self.ui.bZoomOut.setIcon(QIcon(data.app_path+"zoom-out.png"))
+            self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"go-up.png"))
+            self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"go-down.png"))
+            
         self.ui.lblYscale.setText(str(data.Yscale))
 
 
@@ -584,14 +669,10 @@ class frmLogWindow(QtGui.QWidget):
 
 
     def DeleteLogFile(self):
-        reply = QtGui.QMessageBox.question(self, 'Delete Logfile', "Are you sure you want to delete this Logfile?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+        reply = QtGui.QMessageBox.question(self, 'Delete Logfile?', "Are you sure you want to delete this record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
         if reply == QtGui.QMessageBox.Yes:
             print "Delete logfile: "+data.logfilename
             os.remove(data.logfolder+data.logfilename)    
-#            StartWindow.show()
-#            LogWindow.hide()
-#            LoadFileList(+1)
-            #load next file in list
             data.arrLogFileIndex=(data.arrLogFileIndex+1)  % len(data.arrLogFiles)
             data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
             ShowLogFile()
@@ -653,7 +734,7 @@ class frmNoteWindow(QtGui.QWidget):
 class CollectingWindowCanvas(QtGui.QWidget):
     def __init__(self, parent=None):
         QtGui.QWidget.__init__(self, CollectingWindow)    
-        self.setGeometry(9, 230, 782, data.Ysize+30)
+        self.setGeometry(9, 180, 782, data.Ysize+30)
     
     def paintEvent(self, event):
         showGraph(self)
